summaryrefslogtreecommitdiffstats
path: root/server
diff options
context:
space:
mode:
Diffstat (limited to 'server')
-rw-r--r--server/build.xml4
-rw-r--r--server/src/com/vaadin/data/validator/DoubleValidator.java7
-rw-r--r--server/src/com/vaadin/data/validator/IntegerValidator.java7
3 files changed, 15 insertions, 3 deletions
diff --git a/server/build.xml b/server/build.xml
index 253d09a45b..91526dd1c5 100644
--- a/server/build.xml
+++ b/server/build.xml
@@ -33,7 +33,9 @@
</target>
<target name="publish-local" depends="jar">
- <antcall target="common.sources.jar" />
+ <antcall target="common.sources.jar">
+ <reference torefid="extra.jar.includes" refid="server.gwt.includes" />
+ </antcall>
<antcall target="common.javadoc.jar" />
<antcall target="common.publish-local" />
diff --git a/server/src/com/vaadin/data/validator/DoubleValidator.java b/server/src/com/vaadin/data/validator/DoubleValidator.java
index 86aa59381e..55093b6a40 100644
--- a/server/src/com/vaadin/data/validator/DoubleValidator.java
+++ b/server/src/com/vaadin/data/validator/DoubleValidator.java
@@ -15,6 +15,9 @@
*/
package com.vaadin.data.validator;
+import com.vaadin.data.Property;
+import com.vaadin.data.util.converter.StringToDoubleConverter;
+
/**
* String validator for a double precision floating point number. See
* {@link com.vaadin.data.validator.AbstractStringValidator} for more
@@ -22,7 +25,9 @@ package com.vaadin.data.validator;
*
* @author Vaadin Ltd.
* @since 5.4
* @deprecated As of 7.0. Use an Double converter on the field instead.
*/
@Deprecated
@SuppressWarnings("serial")
@@ -22,7 +25,9 @@ package com.vaadin.data.validator;
* @author Vaadin Ltd.
* @since 5.4
- * @deprecated As of 7.0. Use an Double converter on the field instead.
+ * @deprecated As of 7.0. Use a {@link StringToDoubleConverter} converter on the
+ * field instead or bind the field to a {@link Property} of type
+ * {@link Double}.
*/
diff --git a/server/src/com/vaadin/data/validator/IntegerValidator.java b/server/src/com/vaadin/data/validator/IntegerValidator.java
index c3ba699ef2..db2d510946 100644
--- a/server/src/com/vaadin/data/validator/IntegerValidator.java
+++ b/server/src/com/vaadin/data/validator/IntegerValidator.java
@@ -15,6 +15,9 @@
*/
package com.vaadin.data.validator;
+import com.vaadin.data.Property;
+import com.vaadin.data.util.converter.StringToIntegerConverter;
+
/**
* String validator for integers. See
* {@link com.vaadin.data.validator.AbstractStringValidator} for more
@@ -22,7 +25,9 @@ package com.vaadin.data.validator;
*
* @author Vaadin Ltd.
* @since 5.4
* @deprecated As of 7.0. Use an Integer converter on the field instead.
*/
@SuppressWarnings("serial")
@Deprecated
@@ -22,7 +25,9 @@ package com.vaadin.data.validator;
* @author Vaadin Ltd.
* @since 5.4
- * @deprecated As of 7.0. Use an Integer converter on the field instead.
+ * @deprecated As of 7.0. Use a {@link StringToIntegerConverter} converter on
+ * the field instead or bind the field to a {@link Property} of type
+ * {@link Integer}.
*/